<?php

/**
 * Implementiert die Konfiguration der Netzwerkschnittstellen
 * @author Miguel Palmer <mp@beronet.com>
 */
class NetConf {

	/**
	 * Speichert die Netzwerkkonfiguration
	 * @param beroAri $ba
	 * @param beroConf $bc
	 * @return string HTML Code
	 */
	function save($ba, $bc) {

		if ($_POST['action'] == 'apply') {
			# configure basic network settings
			$fields = array('lan-ipaddr', 'lan-netmask', 'lan-gateway',
				'lan-nameserver', 'lan-mtu', 'lan-dhcp', 'wan-dhcp',
				'wan-ipaddr', 'wan-netmask', 'wan-gateway', 'bonding-mode',
				'bonding-miimon', 'bonding-updelay', 'bonding-downdelay');

			# delete every lan setting
			foreach ($fields as $field) {
				$bc->delete('root', $field);
			}

			$bc->set('root', 'lan-mode', sqlite_escape_string($_POST['lan-mode']));

			$bc->set('root', 'lan-dhcp', sqlite_escape_string($_POST['dhcp']));
			if (!in_array($bc->get('root', 'lan-dhcp'), array('yes', '1'))) {
				# configure static networking
				$bc->set('root', 'lan-ipaddr', sqlite_escape_string($_POST['ipaddr']));
				$bc->set('root', 'lan-netmask', sqlite_escape_string($_POST['netmask']));
				$bc->set('root', 'lan-gateway', sqlite_escape_string($_POST['gateway']));
				$bc->set('root', 'lan-mtu', sqlite_escape_string(intval($_POST['lan_mtu'])));

				# configure nameservers
				if (strlen($_POST['lan_nameserver']) != 0) {
					$nameserver = $_POST['lan_nameserver'] . ((strlen($_POST['lan_nameserver2']) != 0) ? ';' . $_POST['lan_nameserver2'] : '');
					$bc->set('root', 'lan-nameserver', sqlite_escape_string($nameserver));
				} else {
					$bc->delete('root', 'lan-nameserver');
				}
			}

			switch ($bc->get('root', 'lan-mode')) {
				case 'lan-wan':
					$bc->delete('root', 'lan-gateway');
					$bc->set('root', 'wan-dhcp', sqlite_escape_string($_POST['wan-dhcp']));
					if ($_POST['wan-dhcp'] != "1") {
						# configure static networking
						$bc->set('root', 'lan-dhcp', sqlite_escape_string("no"));
						$bc->set('root', 'wan-ipaddr', sqlite_escape_string($_POST['wan-ipaddr']));
						$bc->set('root', 'wan-netmask', sqlite_escape_string($_POST['wan-netmask']));
						$bc->set('root', 'wan-gateway', sqlite_escape_string($_POST['wan-gateway']));
					}


					break;
				case 'bonding':
					$bc->set('root', 'bonding-mode', sqlite_escape_string($_POST['bonding-mode']));
					$bc->set('root', 'bonding-miimon', sqlite_escape_string($_POST['bonding-miimon']));
					$bc->set('root', 'bonding-updelay', sqlite_escape_string($_POST['bonding-updelay']));
					$bc->set('root', 'bonding-downdelay', sqlite_escape_string($_POST['bonding-downdelay']));

					break;
			}


			# configure misc. network settings
			$bc->set('root', 'hostname', sqlite_escape_string($_POST['hostname']));
			$bc->set('root', 'ncs_mode', $_POST['ncs_mode']);
			$bc->set('root', 'beroAvahi-enabled', (isset($_POST['beroAvahi-enabled']) ? '1' : '0'));

			# configure vlan
			if (isset($_POST['vlanenable'])) {
				$bc->set('root', 'vlan-enable', sqlite_escape_string($_POST['vlanenable']));
				$bc->set('root', 'vlan-id', sqlite_escape_string($_POST['vlanid']));
				$bc->set('root', 'vlan-prio', sqlite_escape_string($_POST['vlan-prio']));
			} else {
				$bc->delete('root', 'vlan-enable');
				$bc->delete('root', 'vlan-id');
				$bc->delete('root', 'vlan-prio');
			}
			# configure routing
			$routing = '';
			for ($i = 0; $i < count($_POST['route_net']); $i++) {
				if (($_POST['route_net'][$i] != '') && ($_POST['route_netmask'][$i] != '') && ($_POST['route_gateway'][$i] != '')) {
					$routing .= ((strlen($routing) != 0) ? ',' : '') . $_POST['route_net'][$i] . "/" . $_POST['route_netmask'][$i] . "/" . $_POST['route_gateway'][$i];
				}
			}
			$bc->set('root', 'routing', $routing);

			$ret = Helper::activate(3, true, $_GET['m'], ACTIVATE) .
				'<br /><div class="text-center" style="color:red;"><strong>' . NETWORK_CONFIGURATION_APPLIED_DIS . '</strong></div>' . "\n";
		}
		if (isset($_POST['httpsOnly'])) {
			$ba->set('httpsOnly', sqlite_escape_string($_POST['httpsOnly']));
			$option = 1;

			$file_name = $_FILES["uploadfile"]["name"];
			$tmp_file = $_FILES["uploadfile"]["tmp_name"];
			if ($_FILES["uploadfile"]["name"] != "") {
				if ($_FILES["uploadfile"]["size"] > 51200) { //50 kB
					$ret = "<div class='text-center'><img src='./includes/images/punkt_rot.gif'><font color='red'>" . HTTPS_INVALID_FILE_SIZE . "</font></div>";
				} else {
					exec('/usr/local/bin/openssl x509 -in ' . $tmp_file . ' -noout -text', $output, $return);
					if ($return == 0) {
						@unlink("/usr/conf/berofix.pem");
						exec("/bin/cp " . $tmp_file . " /usr/conf/berofix.pem");
						$option = 3;
						$ret .= "<div class='text-center'><img src='./includes/images/punkt_gruen.gif' /><font color='black'>" . SIP_STACKS_UPLOAD_SUCCESS_DIS . "</font></div>";
					} else {
						$ret .= "<div class='text-center'><img src='./includes/images/punkt_rot.gif'><font color='red'>" . HTTPS_INVALID_CERT_ERROR . "</font></div>";
					}
				}
			}
			$ret .= Helper::activate($option, true, $_GET['m'], ACTIVATE);
		}


		return($ret);
	}

	/**
	 * 
	 * @param beroConf $bc
	 * @return string Dropdown LAN-Modus
	 */
	function mode($bc) {
		if ($bc->get('root', 'lan-ports') == 2) {
			$lan_mode = array(
				"single" => "Single mode",
				"lan-wan" => "LAN-WAN",
				"bonding" => "Ethernet bonding");
			$select = '<select class="form-control input-sm" name="lan-mode">';
			foreach ($lan_mode as $mode => $desc) {
				$selected = ($bc->get('root', 'lan-mode') == $mode) ? 'selected' : null;
				$select .= '<option value="' . $mode . '" ' . $selected . '> ' . $desc . ' <br>' . "\n";
			}
			$select .= '</select>';
			ob_start();
			?>
			<div class='form-group'>
				<label for='bonding-mode' class='col-sm-5 control-label'><? echo NETWORK_LAN_MODE_DIS; ?></label>
				<div class='col-sm-4'>
					<? echo $select; ?>
				</div>
			</div>
			<?php
			return ob_get_clean();
		} else {
			return;
		}
	}

	/**
	 * 
	 * @param beroConf $bc
	 * @return string HTML Formular für den Bonding Modus
	 */
	function bonding($bc) {
		$bonding_mode = array(
			"0" => "balance-rr",
			"1" => "active-backup",
			"2" => "balance-xor",
			"3" => "broadcast",
			"4" => "802.3ad",
			"5" => "balance-tlb",
			"6" => "balance-alb",
		);
		if ($bc->get('root', 'bonding-mode') == '')
			$bc->set('root', 'bonding-mode', '1');
		if ($bc->get('root', 'bonding-miimon') == '')
			$bc->set('root', 'bonding-miimon', '100');
		if ($bc->get('root', 'bonding-updelay') == '')
			$bc->set('root', 'bonding-updelay', '200');
		if ($bc->get('root', 'bonding-downdelay') == '')
			$bc->set('root', 'bonding-downdelay', '200');
		$select = '<select name="bonding-mode" class="form-control input-sm">';
		foreach ($bonding_mode as $mode => $desc) {
			$selected = ($bc->get('root', 'bonding-mode') == $mode) ? 'selected' : null;
			$select .= '<option value="' . $mode . '" ' . $selected . '> ' . $desc . ' <br>' . "\n";
		}
		$select .= '</select>';
		ob_start();
		?>
		<?
		return ob_get_clean();
	}

	/**
	 * 
	 * @param beroConf $bc
	 * @return string HTML Formular fur den LAN-WAN Modus
	 */
	function lan_wan($bc) {
		$dhcp = $bc->get("root", "wan-dhcp");
		ob_start();
		?>
		<div id="wan">
			<p class="text-center h5"><? echo NETWORK_WAN_SETTING_DIS; ?></p>
			<div class='form-group'>
				<div class='text-center'>
					<input type="radio" name="wan-dhcp" id="wan-dhcp" onclick="hide_wan($('#wan-static').prop('checked'));"  value="1" 
						   <? echo ($dhcp == "1") ? 'checked' : ''; ?>>&nbsp;
					DHCP
					<input type="radio" name="wan-dhcp" id="wan-static" onclick="hide_wan($('#wan-static').prop('checked'));" value="0" 
						   <? echo ($dhcp) ? '' : ' checked'; ?>>&nbsp;
						   <? echo NETWORK_STATIC_DIS; ?>
				</div>
			</div>
			<div class='form-group' id="wan-ipaddr-tr">
				<label for='wan-ipaddr' class='col-sm-5 control-label'><? echo NETWORK_IP_ADDRESS_DIS; ?></label>
				<div class='col-sm-4'>
					<input name="wan-ipaddr" class="form-control input-sm" type="text" size="15" id="wan-ipaddr" value="<? echo $bc->get('root', 'wan-ipaddr'); ?>">
				</div>
			</div>
			<div class='form-group' id="wan-netmask-tr">
				<label for='wan-netmask' class='col-sm-5 control-label'><? echo NETWORK_NETMASK_DIS; ?></label>
				<div class='col-sm-4'>
					<input name="wan-netmask" class="form-control input-sm" type="text" size="15" id="wan-netmask" value="<? echo $bc->get('root', 'wan-netmask'); ?>">
				</div>
			</div>
			<div class='form-group' id="wan-gateway-tr">
				<label for='wan-gateway' class='col-sm-5 control-label'><? echo NETWORK_GATEWAY_DIS; ?></label>
				<div class='col-sm-4'>
					<input name="wan-gateway" class="form-control input-sm" type="text" size="15" id="wan-gateway" value="<? echo $bc->get('root', 'wan-gateway'); ?>">
				</div>
			</div>
		</div>
		<?php
		return ob_get_clean();
	}

	/**
	 * 
	 * @return string HTML Seite
	 */
	function display() {
		$name = "NETWORK_TITLE_DIS";
		include('./includes/header.php');
		include('/usr/fallback/beroConf.php');

		require_once('./includes/lang.php');

		$bc = new beroConf('root');
		$ba = new beroAri();

		if (!$bc->valid()) {
			$ret .= '<h3>Error:</h3><b>Failed to connect to config database!</b><br />';
			exit(0);
		}

		// args
		$m = $_GET['m'];
		$q = $_GET['q'];
		if (isset($_POST['httpsOnly'])) {
			$ret .= $this->save($ba, $bc);
		} elseif ($_POST['action'] == 'apply') {
			if ($_POST['dhcp'] == 'yes') {
				$ret .= $this->save($ba, $bc);
			} else {
				if ($_POST['ipaddr'] != $_POST['gateway']) {
					$result = exec('/usr/sbin/netconfigverify ' . $_POST['ipaddr'] . ' ' . $_POST['netmask'] . ' ' . $_POST['gateway'] . ' 2>&1');
					if (substr_count($result, 'Failed') > 0) {
						$ret .= '<br /><div class="center"><b><font color="red">' . NETWORK_FAILED_ERROR_DIS . '</font></b></div>' . "\n";
					} else {
						$ret .= $this->save($ba, $bc);
					}
				} else {
					$ret .= '<br /><div class="center"><font color=red><b>' . NETWORK_FAILED_ERROR_DIS . '</b></font></div>' . "\n";
				}
			}
		}


		$iface = $bc->get('root', 'lan-iface');
		$dns = explode(';', $bc->get('root', 'lan-nameserver'));
		$dhcp = in_array($bc->get('root', 'lan-dhcp'), array('yes', '1'));
		//Show default values for DNS and secondary DNS
		if ($dhcp) {
			$dns[0] = '8.8.8.8';
			$dns[1] = '8.8.4.4';
		}

		if ($ba->get('gui_mode') == 'simple')
			$simple_class = 'simple';

		$ncsDetectMode = $bc->get('root', 'ncs_mode');
		ob_start();
		?>
		<br/>
		<form name="networkform" id="networkform" method="POST" class="form-horizontal" action="" onsubmit="return (checkvlan(vlanenable.checked));">
			<input type="hidden" name="action" value="apply" />
			<p class="text-center lead" ><? echo NETWORK_TABLE_HEADER_DIS; ?></p>
			<? echo $this->mode($bc); ?>
			<p class="text-center h5" id="header-lan"><? echo NETWORK_LAN_SETTING_DIS; ?></p>
			<p class="text-center h5" id="header-bonding"><? echo NETWORK_BONDING_SETTING_DIS; ?></p>
			<div class='form-group' id="lan-dhcp-tr">
				<div class='text-center'>
					<input type="radio" name="dhcp" id="lan_dhcp" onclick="hide_netconfig(document.getElementById('lan_static').checked);"
						   data-toggle="tooltip" title="<? echo NET_CONF_DHCP; ?>" value="yes" <? echo ($dhcp) ? ' checked' : ''; ?> />&nbsp;
					DHCP
					<input type="radio" name="dhcp" id="lan_static" onclick="hide_netconfig(document.getElementById('lan_static').checked);"
						   data-toggle="tooltip" title="<? echo NET_CONF_STATIC; ?>" value="no" <? echo ($dhcp) ? '' : ' checked'; ?> />&nbsp;
						   <? echo NETWORK_STATIC_DIS; ?>
				</div>
			</div>
			<div class='form-group' id="lan_ipaddr">
				<label for='ipaddr' class='col-sm-5 control-label'><? echo NETWORK_IP_ADDRESS_DIS; ?></label>
				<div class='col-sm-4'>
					<input name="ipaddr" class="form-control input-sm" type="text" size="15" id="ipaddr" title="<? echo NET_CONF_IP_ADDRESS; ?>" data-toggle="tooltip"
						   value="<? echo $bc->get('root', 'lan-ipaddr'); ?>" />
				</div>
			</div>
			<div class='form-group' id="lan_netmask">
				<label for='netmask' class='col-sm-5 control-label'><? echo NETWORK_NETMASK_DIS; ?></label>
				<div class='col-sm-4'>
					   <input name="netmask" class="form-control input-sm" type="text" size="15" id="netmask" onclick="if (netmask.value == '')
		                                   netmask.value = makeNetMask(ipaddr.value);"
					   title="<? echo NET_CONF_NETMASK; ?>" data-toggle="tooltip" value="<? echo $bc->get('root', 'lan-netmask'); ?>" />
				</div>
			</div>
			<div class='form-group' id="lan_gateway">
				<label for='gateway' class='col-sm-5 control-label'><? echo NETWORK_GATEWAY_DIS; ?></label>
				<div class='col-sm-4'>
					<input name="gateway" class="form-control input-sm" type="text" size="15" id="gateway" title="<? echo NET_CONF_GATEWAY; ?>" data-toggle="tooltip"
						   value="<? echo $bc->get('root', 'lan-gateway'); ?>" />
				</div>
			</div>
			<div class='form-group' id="lan_dns1">
				<label for='lan_nameserver' class='col-sm-5 control-label'><? echo NETWORK_PRIMARY_NAME_SERVER_DIS; ?></label>
				<div class='col-sm-4'>
					<input name="lan_nameserver" class="form-control input-sm" type="text" size="15" id="lan_nameserver" title="<? echo NET_CONF_NAMESERVER; ?>"
						   data-toggle="tooltip" value="<? echo $dns[0]; ?>" />
				</div>
			</div>
			<div class='form-group' id="lan_dns2">
				<label for='lan_nameserver2' class='col-sm-5 control-label'><? echo NETWORK_SECONDARY_NAME_SERVER_DIS; ?></label>
				<div class='col-sm-4'>
					<input name="lan_nameserver2" class="form-control input-sm" type="text" size="15" id="lan_nameserver2" title="<? echo NET_CONF_SECONDARY_NAMESERVER; ?>"
						   data-toggle="tooltip" value="<? echo $dns[1]; ?>" />
				</div>
			</div>
			<div class='form-group' id="lan_hostname">
				<label for='hostname' class='col-sm-5 control-label'><? echo NETWORK_HOSTNAME_DIS; ?></label>
				<div class='col-sm-4'>
					<input name="hostname" class="form-control input-sm" type="text" size="15" checkDigChar="true" id="hostname" value="<? echo $bc->get('root','hostname'); ?>" />
				</div>
			</div>
			<? echo $this->bonding($bc); ?>
			<? echo $this->lan_wan($bc); ?>
			<hr>
			<p class="text-center h5 <? echo $simple_class; ?>" ><? echo NETWORK_ADVANCED_DIS; ?></p>
			<div class='form-group <? echo $simple_class; ?>' id="lan_mtusize">
				<label for='lan_mtu' class='col-sm-5 control-label'><? echo NETWORK_MTU_SIZE_DIS; ?></label>
				<div class='col-sm-4'>
					<input name="lan_mtu" class="form-control input-sm" type="text" size="15" id="lan_mtu" title="<? echo NET_CONF_MTU_SIZE; ?>" data-toggle="tooltip"
						   value="<? echo $bc->get('root', 'lan-mtu'); ?>" />
				</div>
			</div>
			<div class='form-group <? echo $simple_class; ?>'>
				<label for='beroAvahi-enabled' class='col-sm-5 control-label'><? echo NETWORK_AVAHI_DIS; ?></label>
				<div class='col-sm-4'>
					<input type="checkbox" name="beroAvahi-enabled" value="1" <? echo ($bc->get('root', 'beroAvahi-enabled') == '1') ? ' checked' : ''; ?> />
				</div>
			</div>
			<div class='form-group <? echo $simple_class; ?>'>
				<label for='ncs_mode' class='col-sm-5 control-label'><? echo NETWORK_CONFIG_SERVER_DIS; ?></label>
				<div class='col-sm-4'>
					<select name="ncs_mode" class="form-control input-sm">
						<option value="on" <? echo ($ncsDetectMode == 'on') ? ' selected="selected"' : ''; ?>>
							<? echo NETWORK_CONFIG_SERVER_OPTION_ON; ?>
						</option>
						<option value="detectonly" <? echo($ncsDetectMode == 'detectonly') ? ' selected="selected"' : ''; ?>>
							<? echo NETWORK_CONFIG_SERVER_OPTION_OD; ?>
						</option>
						<option value="off" <? echo ($ncsDetectMode == 'off') ? ' selected="selected"' : ''; ?>>
							<? echo NETWORK_CONFIG_SERVER_OPTION_OFF; ?>
						</option>
					</select>
				</div>
			</div>
			<div class='form-group <? echo $simple_class; ?>'>
				<label for='vlanenable' class='col-sm-5 control-label'><? echo NETWORK_VLAN_ENABLE_DIS; ?></label>
				<div class='col-sm-4'>
					<input name="vlanenable" type="checkbox" id="vlanenable" onclick="show_vlan(document.getElementById('vlanenable').checked);" value="1"
						   <? echo ($bc->get('root', 'vlan-enable') == 1) ? ' checked' : ''; ?>/>
				</div>
			</div>
			<div class='form-group <? echo $simple_class; ?>' id="vlan_id">
				<label for='vlanid' class='col-sm-5 control-label'><? echo NETWORK_VLAN_ID_DIS; ?></label>
				<div class='col-sm-4'>
					<input name="vlanid" class="form-control input-sm" type="text" size="15" id="vlanid" value="<? echo $bc->get('root', 'vlan-id'); ?>" />
				</div>
			</div>
			<div class='form-group <? echo $simple_class; ?>' id="vlan_prio">
				<label for='vlan_prio' class='col-sm-5 control-label'><? echo NETWORK_VLAN_PRIORITY_DIS; ?></label>
				<div class='col-sm-4'>
					<? echo $this->vlan_prio(); ?>
				</div>
			</div>
			<? echo $this->routing($simple_class); ?>
			<div class='form-group <? echo $simple_class; ?>' id="add_route">
				<div class='text-center'>
					<input type="button" class="btn btn-default" id="add_route_button" value="<? echo BUTTON_ADD_ROUTE_ENTRY; ?>" />
				</div>
			</div>
			<br>
			<div class="text-center">
				<input type="submit" name="Apply" class="btn btn-default" value="<? echo BUTTON_SAVE; ?>" onmouseover='Tip("<? echo NET_CONF_APPLY; ?>")' onmouseout="UnTip()" />
			</div>
		</form>
		<br>
		<div class="text-center" ><i><? echo REQUIRED_FIELDS; ?></i></div>
		<br />
		<br />
		<hr>
		<? echo $this->httpsSettingTable(); ?>
		<script type="text/javascript" src="misc/script/netconf.js"></script>
		<?php
		$ret .= ob_get_clean();

		return($ret);
	}

	/**
	 * @return string Checkbox httpsOnly
	 */

	function https_only() {
		$ba = new beroAri();
		$proxy_enable = $ba->get("httpsOnly");
		if ($proxy_enable == "1")
			return "<input type='hidden' name='httpsOnly' value='0'>"
				. "<input type='checkbox' name='httpsOnly' value='1' checked>";
		else
			return "<input type='hidden' name='httpsOnly' value='0'>"
				. "<input type='checkbox' name='httpsOnly' value='1'>";
	}

	/**
	 * 
	 * @return string HTML Formular mit den Https Einstellungen
	 */
	function httpsSettingTable() {
		ob_start();
		?>

		<form ENCTYPE="multipart/form-data" class="form-horizontal" action='' method='POST'>
			<input type="hidden" name="m" value="<? echo $_GET['m']; ?>">
			<p class="text-center lead" ><? echo HTTPS_TABLE_HEADER_DIS; ?></p>
			<div class='form-group'>
				<label for='uploadfile' class='col-sm-5 control-label'><? echo HTTPS_UPLOAD_CERTIFICATE_DIS; ?></label>
				<div class='col-sm-4'>
					<input type='file' size='28' name='uploadfile'>
				</div>
			</div>
			<?php if (file_exists("/usr/conf/berofix.pem") && !is_link("/usr/conf/berofix.pem")): ?>
				<div class='form-group'>
					<label for='download' class='col-sm-5 control-label'><? echo HTTPS_CERTIFICATE_DIS; ?></label>
					<div class='col-sm-4'>
						<input type='button' class='btn btn-default' value='<? echo HTTPS_DOWNLOAD_CERTIFICATE_DIS; ?>'
							   onclick=" window.location.href = 'misc/files_download.php?option=certificate_https';">&nbsp;&nbsp;
						<input type='button' class='btn btn-default' value='<? echo HTTPS_DELETE_CERTIFICATE_DIS; ?>'
							   onclick="javascript:if (confirm('<? echo HTTPS_DELETE_CERTIFICATE_MESS_DIS; ?>?') == true)
			                                           window.location.href = 'misc/deletefile.php?m=<? echo $_GET['m']; ?>&option=certificate_https';">
					</div>
				</div>
			<?php endif; ?>
			<div class='form-group'>
				<label for='https_only' class='col-sm-5 control-label'><? echo HTTPS_ONLY_DIS; ?></label>
				<div class='col-sm-4'>
					<? echo $this->https_only(); ?>
				</div>
			</div>

			<div class='text-center'>
				<br>
				<input name='submit' class='btn btn-default' type='submit' value='<? echo BUTTON_SAVE; ?>'>
			</div>
		</form>
		<?php
		return ob_get_clean();
	}

	/**
	 * 
	 * @return string Dropdown VLAN-Prio
	 */
	function vlan_prio() {

		$bc = new beroConf('root');

		$i = 0;
		$ret = '<select name="vlan-prio">' . "\n";
		foreach (array('000', '001', '010', '011', '100', '101', '110', '111') as $bit) {
			$ret .= '<option value="' . $bit . '"' . (($bc->get('root', 'vlan-prio') == $bit) ? ' selected' : '') . '>' . $i++ . '</option>' . "\n";
		}
		$ret .= '</select>' . "\n";

		return($ret);
	}

	/**
	 * @return string Gespeicherte Routen
	 */
	function routing($simple_class = null) {

		$bc = new beroConf('root');
		$routing = $bc->get('root', 'routing');

		if (strlen($routing) == 0) {
			return('');
		}

		$res = '';
		foreach (explode(',', $routing) as $route) {
			list($route_net, $route_netmask, $route_gateway) = explode('/', $route);
			ob_start();
			?>
			<div class='form-group <? echo $simple_class; ?>' >
				<label for='route_net[]' class='col-sm-5 control-label'>Route target</label>
				<div class='col-sm-7'>
					<input name="route_net[]" verifyIP="true" class="net form-control input-sm" style="width:60%; display:inline;" 
						   value="<? echo $route_net; ?>" />
					&nbsp;/&nbsp;
					<input name="route_netmask[]" digits="true" required="true" min="0" max="32" size="2" maxlength="2" style="width:20%; display:inline;" 
						   class="netmask form-control input-sm" value="<? echo $route_netmask; ?>" />
				</div>
			</div>
			<div class='form-group <? echo $simple_mode; ?>'>
				<label for='route_gateway[]' class='col-sm-5 control-label'>Route gateway</label>
				<div class='col-sm-4'>
					<input name="route_gateway[]" verifyIP="true" class="gateway form-control input-sm" value="<? echo $route_gateway; ?>" size="24" />
				</div>
			</div>
			<?php
			$res .= ob_get_clean();
		}

		return($res);
	}

}
?>
